@@ -1,54 +1,3 @@
--- needed post 1.7.0 to fixup continuous aggregates created in 1.7.0 ---
-DO
-$$
-DECLARE
- vname regclass;
- mat_ht_id INTEGER;
- materialized_only bool;
- finalized bool;
- ts_major INTEGER;
- ts_minor INTEGER;
-BEGIN
-    -- procedures with SET clause cannot execute transaction
-    -- control so we adjust search_path in procedure body
-    SET LOCAL search_path TO pg_catalog, pg_temp;
-
-    SELECT ((string_to_array(extversion,'.'))[1])::int, ((string_to_array(extversion,'.'))[2])::int
-    INTO ts_major, ts_minor
-    FROM pg_extension WHERE extname = 'timescaledb';
-
-    IF ts_major >= 2 AND ts_minor >= 7 THEN
-      CREATE PROCEDURE _timescaledb_functions.post_update_cagg_try_repair(
-        cagg_view REGCLASS, force_rebuild BOOLEAN
-      ) AS '@MODULE_PATHNAME@', 'ts_cagg_try_repair' LANGUAGE C;
-    END IF;
-
-    FOR vname, mat_ht_id, materialized_only, finalized IN
-      SELECT format('%I.%I', cagg.user_view_schema, cagg.user_view_name)::regclass, cagg.mat_hypertable_id, cagg.materialized_only, cagg.finalized
-      FROM _timescaledb_catalog.continuous_agg cagg
-    LOOP
-      IF ts_major < 2 THEN
-        EXECUTE format('ALTER VIEW %s SET (timescaledb.materialized_only=%L) ', vname::text, materialized_only);
-
-      ELSIF ts_major = 2 AND ts_minor < 7 THEN
-        EXECUTE format('ALTER MATERIALIZED VIEW %s SET (timescaledb.materialized_only=%L) ', vname::text, materialized_only);
-
-      ELSIF ts_major = 2 AND ts_minor >= 7 THEN
-        SET log_error_verbosity TO VERBOSE;
-        CALL _timescaledb_functions.post_update_cagg_try_repair(vname, false);
-
-      END IF;
-    END LOOP;
-
-    IF ts_major >= 2 AND ts_minor >= 7 THEN
-      DROP PROCEDURE IF EXISTS _timescaledb_functions.post_update_cagg_try_repair(REGCLASS, BOOLEAN);
-    END IF;
-END
-$$ LANGUAGE PLPGSQL;
-
--- can only be dropped after views have been rebuilt
-DROP FUNCTION IF EXISTS _timescaledb_internal.cagg_watermark(oid);
-
 -- For objects that are newly created, we need to set the initprivs to
 -- the initprivs for some table that was created in the installation
 -- of the TimescaleDB extension and not as part of any update.
@@ -107,22 +56,6 @@ UPDATE pg_class cl SET relacl = tmpacl
 
 DROP TABLE _timescaledb_internal.saved_privs;
 
--- Report warning when partial aggregates are used
-DO $$
-DECLARE
-  cagg_name text;
-BEGIN
-    FOR cagg_name IN
-      SELECT
-        format('%I.%I', user_view_schema, user_view_name)
-      FROM _timescaledb_catalog.continuous_agg
-      WHERE finalized IS FALSE
-      ORDER BY 1
-    LOOP
-      RAISE WARNING 'Continuous Aggregate "%" with old format will not be supported in the next version. You should use `cagg_migrate` procedure to migrate to the new format.', cagg_name;
-    END LOOP;
-END $$;
-
 -- Create watermark record when required
 DO
 $$
