@@ -493,7 +493,7 @@ TSCopyMultiInsertBufferFlush(TSCopyMultiInsertInfo *miinfo, TSCopyMultiInsertBuf
 								 NULL /* transition capture */);
 		}
 
-		if (miinfo->has_continuous_aggregate && !ts_guc_enable_cagg_wal_based_invalidation)
+		if (miinfo->has_continuous_aggregate)
 		{
 			bool should_free;
 			HeapTuple tuple = ExecFetchSlotHeapTuple(slots[i], false, &should_free);
@@ -1066,7 +1066,11 @@ copyfrom(CopyChunkState *ccstate, ParseState *pstate, Hypertable *ht, MemoryCont
 
 		Assert(cis != NULL);
 
-		ts_chunk_tuple_routing_decompress_for_insert(cis, myslot, ccstate->ctr->estate, false);
+		ts_chunk_tuple_routing_decompress_for_insert(cis,
+													 ccstate->ctr->root_rri,
+													 myslot,
+													 ccstate->ctr->estate,
+													 false);
 
 		/* Triggers and stuff need to be invoked in query context. */
 		MemoryContextSwitchTo(oldcontext);
