@@ -320,7 +320,7 @@ ts_resolve_hypertable_from_table_or_cagg(Cache *hcache, Oid relid, bool allow_ma
 
 		if (!ht)
 			ereport(ERROR,
-					(errcode(ERRCODE_TS_INTERNAL_ERROR),
+					(errcode(ERRCODE_INTERNAL_ERROR),
 					 errmsg("no materialized table for continuous aggregate"),
 					 errdetail("Continuous aggregate \"%s\" had a materialized hypertable"
 							   " with id %d but it was not found in the hypertable "
@@ -374,9 +374,10 @@ ts_hypertable_id_to_relid(int32 hypertable_id, bool return_invalid)
 
 	ts_scanner_scan(&scanctx);
 
-	Ensure(return_invalid || OidIsValid(relid),
-		   "unable to get valid parent Oid for hypertable %d",
-		   hypertable_id);
+	if (!OidIsValid(relid) && !return_invalid)
+		ereport(ERROR,
+				(errcode(ERRCODE_TS_HYPERTABLE_NOT_EXIST),
+				 errmsg("hypertable with id %d does not exist", hypertable_id)));
 
 	return relid;
 }
@@ -1618,9 +1619,12 @@ ts_hypertable_create_general(PG_FUNCTION_ARGS)
 	 * earlier "ts_hypertable_create" implementation.
 	 */
 	if (IS_CLOSED_DIMENSION(dim_info))
+	{
 		ereport(ERROR,
-				(errmsg("cannot partition using a closed dimension on primary column"),
+				(errcode(ERRCODE_WRONG_OBJECT_TYPE),
+				 errmsg("cannot partition using a closed dimension on primary column"),
 				 errhint("Use range partitioning on the primary column.")));
+	}
 
 	/*
 	 * Current implementation requires to provide a valid chunk sizing function
@@ -2507,19 +2511,21 @@ ts_hypertable_osm_range_update(PG_FUNCTION_ARGS)
 	time_dim = hyperspace_get_open_dimension(ht->space, 0);
 
 	if (time_dim == NULL)
-		elog(ERROR,
-			 "could not find time dimension for hypertable %s.%s",
-			 quote_identifier(NameStr(ht->fd.schema_name)),
-			 quote_identifier(NameStr(ht->fd.table_name)));
+		ereport(ERROR,
+				errcode(ERRCODE_OBJECT_NOT_IN_PREREQUISITE_STATE),
+				errmsg("could not find time dimension for hypertable %s.%s",
+					   quote_identifier(NameStr(ht->fd.schema_name)),
+					   quote_identifier(NameStr(ht->fd.table_name))));
 
 	time_type = ts_dimension_get_partition_type(time_dim);
 
 	int32 osm_chunk_id = ts_chunk_get_osm_chunk_id(ht->fd.id);
 	if (osm_chunk_id == INVALID_CHUNK_ID)
-		elog(ERROR,
-			 "no OSM chunk found for hypertable %s.%s",
-			 quote_identifier(NameStr(ht->fd.schema_name)),
-			 quote_identifier(NameStr(ht->fd.table_name)));
+		ereport(ERROR,
+				errcode(ERRCODE_OBJECT_NOT_IN_PREREQUISITE_STATE),
+				errmsg("no OSM chunk found for hypertable %s.%s",
+					   quote_identifier(NameStr(ht->fd.schema_name)),
+					   quote_identifier(NameStr(ht->fd.table_name))));
 	/*
 	 * range_start, range_end arguments must be converted to internal representation
 	 * a NULL start value is interpreted as INT64_MAX - 1 and a NULL end value is
@@ -2528,7 +2534,9 @@ ts_hypertable_osm_range_update(PG_FUNCTION_ARGS)
 	 * OSM chunk is given upon creation, which is [INT64_MAX - 1, INT64_MAX]
 	 */
 	if ((PG_ARGISNULL(1) && !PG_ARGISNULL(2)) || (!PG_ARGISNULL(1) && PG_ARGISNULL(2)))
-		elog(ERROR, "range_start and range_end parameters must be both NULL or both non-NULL");
+		ereport(ERROR,
+				errcode(ERRCODE_INVALID_PARAMETER_VALUE),
+				errmsg("range_start and range_end parameters must be both NULL or both non-NULL"));
 
 	Oid argtypes[2];
 	for (int i = 0; i < 2; i++)
@@ -2555,7 +2563,9 @@ ts_hypertable_osm_range_update(PG_FUNCTION_ARGS)
 			ts_time_value_to_internal(PG_GETARG_DATUM(2), get_fn_expr_argtype(fcinfo->flinfo, 2));
 
 	if (range_start_internal > range_end_internal)
-		ereport(ERROR, errmsg("dimension slice range_end cannot be less than range_start"));
+		ereport(ERROR,
+				errcode(ERRCODE_INVALID_PARAMETER_VALUE),
+				errmsg("dimension slice range_end cannot be less than range_start"));
 
 	bool osm_chunk_empty = PG_GETARG_BOOL(3);
 
@@ -2584,6 +2594,7 @@ ts_hypertable_osm_range_update(PG_FUNCTION_ARGS)
 	 */
 	if (overlap)
 		ereport(ERROR,
+				errcode(ERRCODE_INVALID_PARAMETER_VALUE),
 				errmsg("attempting to set overlapping range for tiered chunk of %s.%s",
 					   NameStr(ht->fd.schema_name),
 					   NameStr(ht->fd.table_name)),
