@@ -5,7 +5,7 @@
 \c :TEST_DBNAME :ROLE_SUPERUSER
 SET ROLE :ROLE_DEFAULT_PERM_USER;
 
-SELECT _timescaledb_debug.extension_state();
+SELECT _timescaledb_functions.extension_state();
 
 RESET ROLE;
 
@@ -13,7 +13,7 @@ DO $$
 DECLARE
     module text;
 BEGIN
-    SELECT probin INTO module FROM pg_proc WHERE proname = 'extension_state' AND pronamespace = '_timescaledb_debug'::regnamespace;
+    SELECT probin INTO module FROM pg_proc WHERE proname = 'extension_state' AND pronamespace = '_timescaledb_functions'::regnamespace;
     EXECUTE format('CREATE FUNCTION extension_state() RETURNS TEXT AS ''%s'', ''ts_extension_get_state'' LANGUAGE C', module);
 END
 $$;
